/****************************************************************************
** Meta object code from reading C++ file 'columnview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.25.0/src/layouts/columnview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'columnview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ScrollIntentionEventE_t {};
} // unnamed namespace

template <> constexpr inline auto ScrollIntentionEvent::qt_create_metaobjectdata<qt_meta_tag_ZN20ScrollIntentionEventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScrollIntentionEvent",
        "delta",
        "QPointF",
        "accepted"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'delta'
        QtMocHelpers::PropertyData<QPointF>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'accepted'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScrollIntentionEvent, qt_meta_tag_ZN20ScrollIntentionEventE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScrollIntentionEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ScrollIntentionEventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ScrollIntentionEventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ScrollIntentionEventE_t>.metaTypes,
    nullptr
} };

void ScrollIntentionEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScrollIntentionEvent *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QPointF*>(_v) = _t->delta; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->accepted; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: QtMocHelpers::setProperty(_t->accepted, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ScrollIntentionEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScrollIntentionEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ScrollIntentionEventE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScrollIntentionEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ColumnViewAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto ColumnViewAttached::qt_create_metaobjectdata<qt_meta_tag_ZN18ColumnViewAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColumnViewAttached",
        "indexChanged",
        "",
        "fillWidthChanged",
        "reservedSpaceChanged",
        "minimumWidthChanged",
        "preferredWidthChanged",
        "maximumWidthChanged",
        "viewChanged",
        "preventStealingChanged",
        "pinnedChanged",
        "scrollIntention",
        "ScrollIntentionEvent*",
        "event",
        "inViewportChanged",
        "interactiveResizeEnabledChanged",
        "interactiveResizingChanged",
        "globalHeaderChanged",
        "QQuickItem*",
        "oldHeader",
        "newHeader",
        "globalFooterChanged",
        "oldFooter",
        "newFooter",
        "index",
        "fillWidth",
        "reservedSpace",
        "minimumWidth",
        "preferredWidth",
        "maximumWidth",
        "preventStealing",
        "pinned",
        "view",
        "ColumnView*",
        "inViewport",
        "interactiveResizeEnabled",
        "interactiveResizing",
        "globalHeader",
        "globalFooter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'indexChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillWidthChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reservedSpaceChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumWidthChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferredWidthChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumWidthChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preventStealingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pinnedChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollIntention'
        QtMocHelpers::SignalData<void(ScrollIntentionEvent *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'inViewportChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interactiveResizeEnabledChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interactiveResizingChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalHeaderChanged'
        QtMocHelpers::SignalData<void(QQuickItem *, QQuickItem *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 18, 20 },
        }}),
        // Signal 'globalFooterChanged'
        QtMocHelpers::SignalData<void(QQuickItem *, QQuickItem *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 22 }, { 0x80000000 | 18, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'index'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'fillWidth'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'reservedSpace'
        QtMocHelpers::PropertyData<qreal>(26, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'minimumWidth'
        QtMocHelpers::PropertyData<qreal>(27, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'preferredWidth'
        QtMocHelpers::PropertyData<qreal>(28, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'maximumWidth'
        QtMocHelpers::PropertyData<qreal>(29, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'preventStealing'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'pinned'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8),
        // property 'view'
        QtMocHelpers::PropertyData<ColumnView*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 6),
        // property 'inViewport'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 10),
        // property 'interactiveResizeEnabled'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'interactiveResizing'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'globalHeader'
        QtMocHelpers::PropertyData<QQuickItem*>(37, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 13),
        // property 'globalFooter'
        QtMocHelpers::PropertyData<QQuickItem*>(38, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 14),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColumnViewAttached, qt_meta_tag_ZN18ColumnViewAttachedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColumnViewAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColumnViewAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColumnViewAttachedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ColumnViewAttachedE_t>.metaTypes,
    nullptr
} };

void ColumnViewAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColumnViewAttached *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->indexChanged(); break;
        case 1: _t->fillWidthChanged(); break;
        case 2: _t->reservedSpaceChanged(); break;
        case 3: _t->minimumWidthChanged(); break;
        case 4: _t->preferredWidthChanged(); break;
        case 5: _t->maximumWidthChanged(); break;
        case 6: _t->viewChanged(); break;
        case 7: _t->preventStealingChanged(); break;
        case 8: _t->pinnedChanged(); break;
        case 9: _t->scrollIntention((*reinterpret_cast<std::add_pointer_t<ScrollIntentionEvent*>>(_a[1]))); break;
        case 10: _t->inViewportChanged(); break;
        case 11: _t->interactiveResizeEnabledChanged(); break;
        case 12: _t->interactiveResizingChanged(); break;
        case 13: _t->globalHeaderChanged((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        case 14: _t->globalFooterChanged((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ScrollIntentionEvent* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::indexChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::fillWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::reservedSpaceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::minimumWidthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::preferredWidthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::maximumWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::viewChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::preventStealingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::pinnedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)(ScrollIntentionEvent * )>(_a, &ColumnViewAttached::scrollIntention, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::inViewportChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::interactiveResizeEnabledChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)()>(_a, &ColumnViewAttached::interactiveResizingChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)(QQuickItem * , QQuickItem * )>(_a, &ColumnViewAttached::globalHeaderChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnViewAttached::*)(QQuickItem * , QQuickItem * )>(_a, &ColumnViewAttached::globalFooterChanged, 14))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ColumnView* >(); break;
        case 13:
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->index(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->fillWidth(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->reservedSpace(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->minimumWidth(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->preferredWidth(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->maximumWidth(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->preventStealing(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isPinned(); break;
        case 8: *reinterpret_cast<ColumnView**>(_v) = _t->view(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->inViewport(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->interactiveResizeEnabled(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->interactiveResizing(); break;
        case 12: *reinterpret_cast<QQuickItem**>(_v) = _t->globalHeader(); break;
        case 13: *reinterpret_cast<QQuickItem**>(_v) = _t->globalFooter(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIndex(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setFillWidth(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setReservedSpace(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setMinimumWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setPreferredWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setMaximumWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setPreventStealing(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setPinned(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setInteractiveResizeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setInteractiveResizing(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setGlobalHeader(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 13: _t->setGlobalFooter(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ColumnViewAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColumnViewAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ColumnViewAttachedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ColumnViewAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void ColumnViewAttached::indexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ColumnViewAttached::fillWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ColumnViewAttached::reservedSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ColumnViewAttached::minimumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ColumnViewAttached::preferredWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ColumnViewAttached::maximumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ColumnViewAttached::viewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ColumnViewAttached::preventStealingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ColumnViewAttached::pinnedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ColumnViewAttached::scrollIntention(ScrollIntentionEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ColumnViewAttached::inViewportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ColumnViewAttached::interactiveResizeEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void ColumnViewAttached::interactiveResizingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ColumnViewAttached::globalHeaderChanged(QQuickItem * _t1, QQuickItem * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void ColumnViewAttached::globalFooterChanged(QQuickItem * _t1, QQuickItem * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN10ColumnViewE_t {};
} // unnamed namespace

template <> constexpr inline auto ColumnView::qt_create_metaobjectdata<qt_meta_tag_ZN10ColumnViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColumnView",
        "QML.Element",
        "auto",
        "QML.Attached",
        "ColumnViewAttached",
        "DefaultProperty",
        "contentData",
        "itemInserted",
        "",
        "position",
        "QQuickItem*",
        "item",
        "itemRemoved",
        "contentChildrenChanged",
        "columnResizeModeChanged",
        "columnWidthChanged",
        "currentIndexChanged",
        "currentItemChanged",
        "visibleItemsChanged",
        "countChanged",
        "draggingChanged",
        "movingChanged",
        "contentXChanged",
        "contentWidthChanged",
        "interactiveChanged",
        "acceptsMouseChanged",
        "scrollDurationChanged",
        "separatorVisibleChanged",
        "leadingVisibleItemChanged",
        "trailingVisibleItemChanged",
        "topPaddingChanged",
        "bottomPaddingChanged",
        "savedStateChanged",
        "addItem",
        "removeItem",
        "QVariant",
        "insertItem",
        "pos",
        "replaceItem",
        "moveItem",
        "from",
        "to",
        "clear",
        "containsItem",
        "itemAt",
        "x",
        "y",
        "get",
        "index",
        "pop",
        "columnResizeMode",
        "ColumnResizeMode",
        "columnWidth",
        "count",
        "currentIndex",
        "currentItem",
        "contentItem",
        "contentX",
        "contentWidth",
        "topPadding",
        "bottomPadding",
        "scrollDuration",
        "separatorVisible",
        "visibleItems",
        "QList<QQuickItem*>",
        "leadingVisibleItem",
        "trailingVisibleItem",
        "dragging",
        "moving",
        "interactive",
        "acceptsMouse",
        "contentChildren",
        "QQmlListProperty<QQuickItem>",
        "QQmlListProperty<QObject>",
        "savedState",
        "FixedColumns",
        "DynamicColumns",
        "SingleColumn"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemInserted'
        QtMocHelpers::SignalData<void(int, QQuickItem *)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'itemRemoved'
        QtMocHelpers::SignalData<void(QQuickItem *)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'contentChildrenChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'columnResizeModeChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'columnWidthChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentItemChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleItemsChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'draggingChanged'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'movingChanged'
        QtMocHelpers::SignalData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentXChanged'
        QtMocHelpers::SignalData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentWidthChanged'
        QtMocHelpers::SignalData<void()>(23, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interactiveChanged'
        QtMocHelpers::SignalData<void()>(24, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'acceptsMouseChanged'
        QtMocHelpers::SignalData<void()>(25, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollDurationChanged'
        QtMocHelpers::SignalData<void()>(26, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'separatorVisibleChanged'
        QtMocHelpers::SignalData<void()>(27, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leadingVisibleItemChanged'
        QtMocHelpers::SignalData<void()>(28, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trailingVisibleItemChanged'
        QtMocHelpers::SignalData<void()>(29, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topPaddingChanged'
        QtMocHelpers::SignalData<void()>(30, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomPaddingChanged'
        QtMocHelpers::SignalData<void()>(31, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'savedStateChanged'
        QtMocHelpers::SignalData<void()>(32, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void(QQuickItem *)>(33, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'removeItem'
        QtMocHelpers::SlotData<QQuickItem *(const QVariant &)>(34, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 35, 11 },
        }}),
        // Slot 'insertItem'
        QtMocHelpers::SlotData<void(int, QQuickItem *)>(36, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 37 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'replaceItem'
        QtMocHelpers::SlotData<void(int, QQuickItem *)>(38, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 37 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'moveItem'
        QtMocHelpers::SlotData<void(int, int)>(39, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(42, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'containsItem'
        QtMocHelpers::SlotData<bool(QQuickItem *)>(43, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'itemAt'
        QtMocHelpers::SlotData<QQuickItem *(qreal, qreal)>(44, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QReal, 45 }, { QMetaType::QReal, 46 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QQuickItem *(int)>(47, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Int, 48 },
        }}),
        // Method 'pop'
        QtMocHelpers::MethodData<QQuickItem *(const QVariant &)>(49, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 35, 11 },
        }}),
        // Method 'pop'
        QtMocHelpers::MethodData<QQuickItem *()>(49, 8, QMC::AccessPublic, 0x80000000 | 10),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'columnResizeMode'
        QtMocHelpers::PropertyData<enum ColumnResizeMode>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'columnWidth'
        QtMocHelpers::PropertyData<qreal>(52, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'count'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'currentItem'
        QtMocHelpers::PropertyData<QQuickItem*>(55, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 6),
        // property 'contentItem'
        QtMocHelpers::PropertyData<QQuickItem*>(56, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'contentX'
        QtMocHelpers::PropertyData<qreal>(57, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 11),
        // property 'contentWidth'
        QtMocHelpers::PropertyData<qreal>(58, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 12),
        // property 'topPadding'
        QtMocHelpers::PropertyData<qreal>(59, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 19),
        // property 'bottomPadding'
        QtMocHelpers::PropertyData<qreal>(60, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 20),
        // property 'scrollDuration'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 15),
        // property 'separatorVisible'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 16),
        // property 'visibleItems'
        QtMocHelpers::PropertyData<QList<QQuickItem*>>(63, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 7),
        // property 'leadingVisibleItem'
        QtMocHelpers::PropertyData<QQuickItem*>(65, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 17),
        // property 'trailingVisibleItem'
        QtMocHelpers::PropertyData<QQuickItem*>(66, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 18),
        // property 'dragging'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'moving'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 10),
        // property 'interactive'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 13),
        // property 'acceptsMouse'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 14),
        // property 'contentChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuickItem>>(71, 0x80000000 | 72, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'contentData'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(6, 0x80000000 | 73, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'savedState'
        QtMocHelpers::PropertyData<QString>(74, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColumnResizeMode'
        QtMocHelpers::EnumData<enum ColumnResizeMode>(51, 51, QMC::EnumFlags{}).add({
            {   75, ColumnResizeMode::FixedColumns },
            {   76, ColumnResizeMode::DynamicColumns },
            {   77, ColumnResizeMode::SingleColumn },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ColumnView, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ColumnView::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ColumnViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ColumnViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ColumnViewE_t>.metaTypes,
    nullptr
} };

void ColumnView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColumnView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        case 1: _t->itemRemoved((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 2: _t->contentChildrenChanged(); break;
        case 3: _t->columnResizeModeChanged(); break;
        case 4: _t->columnWidthChanged(); break;
        case 5: _t->currentIndexChanged(); break;
        case 6: _t->currentItemChanged(); break;
        case 7: _t->visibleItemsChanged(); break;
        case 8: _t->countChanged(); break;
        case 9: _t->draggingChanged(); break;
        case 10: _t->movingChanged(); break;
        case 11: _t->contentXChanged(); break;
        case 12: _t->contentWidthChanged(); break;
        case 13: _t->interactiveChanged(); break;
        case 14: _t->acceptsMouseChanged(); break;
        case 15: _t->scrollDurationChanged(); break;
        case 16: _t->separatorVisibleChanged(); break;
        case 17: _t->leadingVisibleItemChanged(); break;
        case 18: _t->trailingVisibleItemChanged(); break;
        case 19: _t->topPaddingChanged(); break;
        case 20: _t->bottomPaddingChanged(); break;
        case 21: _t->savedStateChanged(); break;
        case 22: _t->addItem((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 23: { QQuickItem* _r = _t->removeItem((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 24: _t->insertItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        case 25: _t->replaceItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        case 26: _t->moveItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 27: _t->clear(); break;
        case 28: { bool _r = _t->containsItem((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { QQuickItem* _r = _t->itemAt((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 30: { QQuickItem* _r = _t->get((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 31: { QQuickItem* _r = _t->pop((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 32: { QQuickItem* _r = _t->pop();
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)(int , QQuickItem * )>(_a, &ColumnView::itemInserted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)(QQuickItem * )>(_a, &ColumnView::itemRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::contentChildrenChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::columnResizeModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::columnWidthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::currentIndexChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::currentItemChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::visibleItemsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::countChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::draggingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::movingChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::contentXChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::contentWidthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::interactiveChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::acceptsMouseChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::scrollDurationChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::separatorVisibleChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::leadingVisibleItemChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::trailingVisibleItemChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::topPaddingChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::bottomPaddingChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColumnView::*)()>(_a, &ColumnView::savedStateChanged, 21))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QQuickItem*> >(); break;
        case 14:
        case 13:
        case 5:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ColumnResizeMode*>(_v) = _t->columnResizeMode(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->columnWidth(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        case 4: *reinterpret_cast<QQuickItem**>(_v) = _t->currentItem(); break;
        case 5: *reinterpret_cast<QQuickItem**>(_v) = _t->contentItem(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->contentX(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->contentWidth(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->topPadding(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->bottomPadding(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->scrollDuration(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->separatorVisible(); break;
        case 12: *reinterpret_cast<QList<QQuickItem*>*>(_v) = _t->visibleItems(); break;
        case 13: *reinterpret_cast<QQuickItem**>(_v) = _t->leadingVisibleItem(); break;
        case 14: *reinterpret_cast<QQuickItem**>(_v) = _t->trailingVisibleItem(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->dragging(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->moving(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->interactive(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->acceptsMouse(); break;
        case 19: *reinterpret_cast<QQmlListProperty<QQuickItem>*>(_v) = _t->contentChildren(); break;
        case 20: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->contentData(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->savedState(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColumnResizeMode(*reinterpret_cast<enum ColumnResizeMode*>(_v)); break;
        case 1: _t->setColumnWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setCurrentIndex(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setContentX(*reinterpret_cast<qreal*>(_v)); break;
        case 8: _t->setTopPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 9: _t->setBottomPadding(*reinterpret_cast<qreal*>(_v)); break;
        case 10: _t->setScrollDuration(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setSeparatorVisible(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setInteractive(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setAcceptsMouse(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setSavedState(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ColumnView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColumnView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ColumnViewE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ColumnView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void ColumnView::itemInserted(int _t1, QQuickItem * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ColumnView::itemRemoved(QQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ColumnView::contentChildrenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ColumnView::columnResizeModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ColumnView::columnWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ColumnView::currentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ColumnView::currentItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ColumnView::visibleItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ColumnView::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ColumnView::draggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ColumnView::movingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ColumnView::contentXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void ColumnView::contentWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ColumnView::interactiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ColumnView::acceptsMouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ColumnView::scrollDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void ColumnView::separatorVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void ColumnView::leadingVisibleItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void ColumnView::trailingVisibleItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void ColumnView::topPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void ColumnView::bottomPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void ColumnView::savedStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
